@@ -1,7 +1,9 @@
 #include "ZepMaxdef.h"
        integer Nevrun   ! event counter generated in this run
        integer iowk     ! logical  device number used for input disk file
-       integer IoTrace  ! logical device number of trace info.
+       integer IoTrace  ! logical device number of trace info. 
+                        ! If >0, only charged ptcl tracks are recorded
+           	        ! If <0, abs is used. neutral ptcl tracks also recorded
        character*128 TraceDir   ! The director where you take trace info
        integer MaxMediaDir  ! max number of directories where
                             ! media file is searched for.
@@ -9,9 +11,11 @@
                             ! 1--> some usefule/warning level info.
                             ! 2--> more details.
        integer epHooks(3)   ! number of c, i, r variables user wants to 
-                            ! define and inut from epicsfile(epHookc/i/r)
+                            ! define and input from epicsfile(epHookc/i/r)
        integer Ioprim       ! primary container.  code subcode ...etc
+
        integer Inpxyz, Inpdir, Inperg, Inpsubcode, Inptime
+
        parameter(MaxMediaDir = MAX_MEDIA_DIR)
        parameter( iowk = 11, Ioprim=15 )
        character*128 MediaDir(MaxMediaDir)
