@@ -19,19 +19,17 @@ c                       1-->length obtained. pos  is  outside
 c                      -1-->not cross 
 
 c           compute the minimum length to the boundary
-      if(comp.struc(1:8) .eq. 'angle') then
-         call epbangle(comp, posl, dirl,  length, icon)
-      elseif(comp.struc(1:8) .eq. 'sqpipe') then
-         call epbsqpipe(comp, posl, dirl, length, icon)
+      if(comp.struc(1:8) .eq. 'cone') then
+         call epbcone(comp, posl, dirl,  length, icon)
+      elseif(comp.struc(1:8) .eq. 'ecyl') then
+         call epbecyl(comp, posl, dirl, length, icon)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epb%2(comp, posl, dirl,  length, icon)
       else
          call cerrorMsg(comp.struc(1:8), 1)
          call cerrorMsg(' is not supported: epbNew. Maybe', 1)
          call cerrorMsg(
-     *   " You haven't done mkNewVolume 'your-config-file' ?", 1)
-         call cerrorMsg(
-     *   "Goto Util and do that", 1)
+     *   " You haven't done mkNewVolume 'your-config-file'", 0)
       endif
 
       end
@@ -47,10 +45,10 @@ c             see if pos is inside the comp component
       record /epPos/pos  ! input. given point
       integer icon  !   output.  0-->inside. 1-->outside
 
-      if(comp.struc(1:8) .eq. 'angle')  then
-         call epsangle(comp, pos, icon)
-      elseif(comp.struc(1:8) .eq. 'sqpipe') then
-         call epssqpipe(comp, pos, icon)
+      if(comp.struc(1:8) .eq. 'cone')  then
+         call epscone(comp, pos, icon)
+      elseif(comp.struc(1:8) .eq. 'ecyl') then
+         call epsecyl(comp, pos, icon)
 c---  elseif(comp.struc(1:8) .eq. '%2')  then
 c---     call eps%2(comp, pos, icon)
       else
@@ -70,10 +68,10 @@ c     ***********************************
       character*(*)  shape     ! input.  config data has this shape
 c            read configuration data 
 
-      if(shape(1:8)  .eq. 'angle') then
-         call eprangle(comp)
-      elseif(shape(1:8) .eq. 'sqpipe') then
-         call eprsqpipe(comp)
+      if(shape(1:8)  .eq. 'cone') then
+         call eprcone(comp)
+      elseif(shape(1:8) .eq. 'ecyl') then
+         call eprecyl(comp)
 c---  elseif(shape(1:8)  .eq. '%2') then
 c---     call epr%2(comp)
       else
@@ -96,10 +94,10 @@ c
       record /epPos/ orig      ! output. origin
       record /ep3Vec/ abc      ! output. a,b,c of the box.
 
-      if(comp.struc(1:8) .eq. 'angle') then
-         call epenvlpangle(comp, orig, abc)
-      elseif(comp.struc(1:8) .eq. 'sqpipe') then
-         call epenvlpsqpipe(comp, orig, abc)
+      if(comp.struc(1:8) .eq. 'cone') then
+         call epenvlpcone(comp, orig, abc)
+      elseif(comp.struc(1:8) .eq. 'ecyl') then
+         call epenvlpecyl(comp, orig, abc)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epenvlp%2(comp, orig, abc)
       else
@@ -120,10 +118,10 @@ c
                          !  the config file. It's value is in 
                          !  Volat( comp.vol + loc(i)).
                          !  loc size must be >= comp.Nattributes
-      if(comp.struc(1:8) .eq. 'angle') then
-         call epatlocangle(comp, loc)
-      elseif(comp.struc(1:8) .eq. 'sqpipe') then
-         call epatlocsqpipe(comp, loc)
+      if(comp.struc(1:8) .eq. 'cone') then
+         call epatloccone(comp, loc)
+      elseif(comp.struc(1:8) .eq. 'ecyl') then
+         call epatlocecyl(comp, loc)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epatloc%2(comp, loc)
       else
