@@ -15,6 +15,10 @@ c
       integer icon   !  output 0 --> normal. pos, el found
                      !         1 --> something wrong. adjuested safely.
                      !               pos. el obtained  
+                     !         2---> ptcl is near void and judged
+                     !               inside at some place and
+                     !               in void at other place. so 
+                     !               discard it.
       character*120 msg
       real*8  tmpel, el2, el
       integer i, cnxx, j, cnx, jcon
@@ -32,13 +36,16 @@ c         issue messages.
 
          Bndryerr = Bndryerr + 1    ! count it
          call eppos2cn(Cn, cTrack, cnxx)
-
+         if(cnxx .ge. Det.nct) then
+            icon = 2
+            return !  *******
+         endif
          call cerrorMsg(
      *    'If this message comes out at the very beginning of', 1)
          call cerrorMsg(
      *    ' an event, better to suspect that your incident particle',1)
          call cerrorMsg(
-     *     'direction might be wrong; check it.!!!!!', 1)
+     *    'direction might be wrong; check it.!!!!!', 1)
          call cerrorMsg(
      *    'If not,  a particle on or very near to a ', 1)
          call cerrorMsg(
@@ -86,32 +93,32 @@ c         issue messages.
          jcon = 0
       else
 c          partial  container's boundary, if any, may be closer
-        do j = 1, Det.cmp(Cn).NPContainer
+         do j = 1, Det.cmp(Cn).NPContainer
 c((((((((((
 c           cnx = Det.cmp(Cn).PContained(j)
-           cnx = CnArea(Det.cmp(Cn).PContained+j)
+            cnx = CnArea(Det.cmp(Cn).PContained+j)
 c))))))))))))
-           call  epbndry2(cnx,  el2, jcon)
-           if(jcon  .eq. 0) then
-              if(el2 .lt.  el) then
-                 el = el2
-              endif
-           endif
-        enddo
+            call  epbndry2(cnx,  el2, jcon)
+            if(jcon  .eq. 0) then
+               if(el2 .lt.  el) then
+                  el = el2
+               endif
+            endif
+         enddo
 c          Matreska may be in between
-        do i = 1, Det.cmp(Cn).NMatreska
+         do i = 1, Det.cmp(Cn).NMatreska
 c((((((((((((((((
 c           call epbndry2(Det.cmp(Cn).Contains(i),  tmpel, jcon)
-          call epbndry2(CnArea( Det.cmp(Cn).Contains+i),  tmpel, jcon)
+            call epbndry2(CnArea( Det.cmp(Cn).Contains+i),  tmpel, jcon)
 c))))))))))
-           if(jcon .eq. 1 .and. tmpel .lt. el) then
-              el = tmpel
-           endif
-        enddo
-        pos.x = cTrack.pos.x + el*cTrack.w.x
-        pos.y = cTrack.pos.y + el*cTrack.w.y
-        pos.z = cTrack.pos.z + el*cTrack.w.z
-        icon = 0
+            if(jcon .eq. 1 .and. tmpel .lt. el) then
+               el = tmpel
+            endif
+         enddo
+         pos.x = cTrack.pos.x + el*cTrack.w.x
+         pos.y = cTrack.pos.y + el*cTrack.w.y
+         pos.z = cTrack.pos.z + el*cTrack.w.z
+         icon = 0
       endif
       end
       subroutine epbndry2(cnx, el, icon)
@@ -260,7 +267,19 @@ c
      *      Volat(comp.vol+prismc), Volat(comp.vol+prismh),
      *      el, jcon)
         end
+      subroutine epnewComp
+      implicit none
+#include "ZepTrackv.h"
+#include "Zcnfig.h"
+c         when a particle moves  to a new component
+c         the following must be done
+      Cn = cTrack.cn
+      MediaNo = Det.Cn2media(Cn)
 
-
-
-
+c       r.l                         cm   / X0           
+      MaxPath =abs( Det.cmp(Cn).MaxPathL/Media(MediaNo).X0)
+c         Det.cmp(Cn).MaxPathL may be < 0; which means
+c        that the value is set by Epics and abs should be used.
+c         already dummy
+      call ep2cosCond(Media(MediaNo).Aeff, Media(MediaNo).Zeff)
+      end
